#'---
#'title: "Codebook | Corpus der Entscheidungen des Bundesverfassungsgerichts"
#'author: Seán Fobbe
#'geometry: margin=3cm
#'papersize: a4
#'fontsize: 11pt
#'output:
#'  pdf_document:
#'    toc: true
#'    toc_depth: 3
#'    number_sections: true
#'    pandoc_args: --listings
#'    includes:
#'      in_header: General_Source_TEX_Preamble_DE.tex
#'      before_body: [CE-BVerfG_Source_TEX_Definitions.tex,CE-BVerfG_Source_TEX_CodebookTitle.tex]
#'bibliography: packages.bib
#'nocite: '@*'
#' ---

#'\newpage

#+ echo = FALSE 
knitr::opts_chunk$set(fig.width=12,
                      fig.height=8,
                      fig.pos = "center",
                      echo=FALSE,
                      warning=FALSE,
                      message=FALSE)


############################
### Packages
############################

#+

library(knitr)        # Professionelles Reporting
library(kableExtra)   # Verbesserte Automatisierte Tabellen
library(magick)       # Fortgeschrittene Verarbeitung von Grafiken
library(parallel)     # Parallelisierung in Base R
library(ggplot2)      # Fortgeschrittene Datenvisualisierung
library(scales)       # Log-Skalen
library(data.table)   # Fortgeschrittene Datenverarbeitung



###################################
### Zusätzliche Funktionen einlesen
###################################

source("General_Source_Functions.R")



############################
### Vorbereitung
############################

datasetname <- "CE-BVerfG"
doi.concept <- "10.5281/zenodo.3902658" # checked
doi.version <- "10.5281/zenodo.4308215" # checked


files.zip <- list.files(pattern="\\.zip")
datestamp <- unique(tstrsplit(files.zip, split="_")[[2]])



prefix <- paste0("ANALYSE/", datasetname, "_")



############################
### Tabellen einlesen
############################

table.spruch <- fread(paste0(prefix, "01_Frequenztabelle_var-spruchkoerper_az.csv"))[,c(1:2,4:5)]
table.regz <- fread(paste0(prefix, "01_Frequenztabelle_var-registerzeichen.csv"))[,c(1:2,4:5)]
table.jahr.eingangISO <- fread(paste0(prefix, "01_Frequenztabelle_var-eingangsjahr_iso.csv"))
table.jahr.entscheid <- fread(paste0(prefix, "01_Frequenztabelle_var-entscheidungsjahr.csv"))[,c(1:2,4:5)]
table.output.praesi <- fread(paste0(prefix, "01_Frequenztabelle_var-praesi.csv"))[,c(1:2,4:5)]
table.output.vpraesi <- fread(paste0(prefix, "01_Frequenztabelle_var-v_praesi.csv"))[,c(1:2,4:5)]

stats.ling <-  fread(paste0(prefix, "00_KorpusStatistik_ZusammenfassungLinguistisch.csv"))
stats.docvars <- fread(paste0(prefix, "00_KorpusStatistik_ZusammenfassungDocvarsQuantitativ.csv"))

table.praesi <- fread("C-BVerfGE_Source_Variablen_Praesident.csv")
table.vpraesi <- fread("C-BVerfGE_Source_Variablen_VizePraesident.csv")



summary.corpus <- fread(paste(datasetname, datestamp, "DE_CSV_Metadaten.csv", sep = "_"))

hashfile <- paste(datasetname, datestamp, "KryptographischeHashes.csv", sep = "_")

signaturefile <- paste(datasetname, datestamp, "FobbeSignatur.gpg", sep = "_")





#'# Einführung

#' Das **Bundesverfassungsgericht (BVerfG)** ist das höchste Gericht der Bundesrepublik Deutschland und ein Verfassungsorgan. Als \enquote{Hüter der Verfassung} ist es seit seiner Gründung im Jahr 1951 mit der Auslegung und Durchsetzung des Grundgesetzes betraut.
#'
#' Seine Bedeutung im Verfassungsgefüge der Bundesrepublik Deutschland ist kaum zu überschätzen. So richtet es nicht nur über Streitigkeiten zwischen Verfassungsorganen und über Normenkontrollanträge, welche die Nichtigkeit von Gesetzen zur Folge haben können, sondern auch über \enquote{Verfassungsbeschwerden, die von jedermann mit der Behauptung erhoben werden können, durch die öffentliche Gewalt in einem seiner Grundrechte oder in einem seiner [grundrechtsgleichen Rechte] verletzt zu sein} (Art. 93 Abs. 4b GG). Das Instrument der Verfassungsbeschwerde ist in seiner Beliebtheit und Effektivität in der Geschichte Deutschlands beispiellos und von hoher wissenschaftlicher und praktischer Bedeutung. In nicht wenigen Verfahrensarten haben die Entscheidungen des BVerfG zudem Gesetzeskraft (§ 31 Abs. 2 BVerfGG).
#'
#' 
#'Die quantitative Analyse von juristischen Texten, insbesondere denen des Bundesverfassungsgerichts, ist in den deutschen Rechtswissenschaften ein noch junges und kaum bearbeitetes Feld.\footnote{Besonders positive Ausnahmen finden sich unter: \url{https://www.quantitative-rechtswissenschaft.de/}} Zu einem nicht unerheblichen Teil liegt dies auch daran, dass die Anzahl an frei nutzbaren Datensätzen außerordentlich gering ist.
#' 
#'Die meisten hochwertigen Datensätze lagern (fast) unerreichbar in kommerziellen Datenbanken und sind wissenschaftlich gar nicht oder nur gegen Entgelt zu nutzen. Frei verfügbare Datenbanken wie \emph{Opinio Iuris}\footnote{\url{https://opinioiuris.de/}} und \emph{openJur}\footnote{\url{https://openjur.de/}} verbieten ausdrücklich das maschinelle Auslesen der Rohdaten.\footnote{Openjur beabsichtigt eine API anzubieten, diese war aber im November 2020 immernoch nicht verfügbar. Openjur ist seit 2008 in Betrieb.} Wissenschaftliche Initiativen wie der Juristische Referenzkorpus (JuReKo) sind nach jahrelanger Arbeit hinter verschlossenen Türen verschwunden.
#' 
#'In einem funktionierenden Rechtsstaat muss die Rechtsprechung öffentlich, transparent und nachvollziehbar sein. Im 21. Jahrhundert bedeutet dies auch, dass sie quantitativen Analysen zugänglich sein muss. Der Erstellung und Aufbereitung des Datensatzes liegen daher die Prinzipien der allgemeinen Verfügbarkeit durch Urheberrechtsfreiheit, strenge Transparenz und vollständige wissenschaftliche Reproduzierbarkeit zugrunde. Die FAIR-Prinzipien (Findable, Accessible, Interoperable and Reusable) für freie wissenschaftliche Daten inspirieren sowohl die Konstruktion, als auch die Art der Publikation.\footnote{Wilkinson, M., Dumontier, M., Aalbersberg, I. et al. The FAIR Guiding Principles for Scientific Data Management and Stewardship. Sci Data 3, 160018 (2016). \url{https://doi.org/10.1038/sdata.2016.18}}




#+
#'# Nutzung

#' Die Daten sind in offenen, interoperablen und weit verbreiteten Formaten (CSV, TXT, PDF) veröffentlicht. Sie lassen sich grundsätzlich mit allen modernen Programmiersprachen (z.B. Python oder R), sowie mit grafischen Programmen nutzen.
#'
#' **Wichtig:** Nicht vorhandene Werte sind sowohl in den Dateinamen als auch in der CSV-Datei mit "NA" codiert.

#+
#'## CSV-Dateien
#' Am einfachsten ist es die **CSV-Dateien** einzulesen. CSV-Dateien\footnote{Das CSV-Format ist in RFC 4180 definiert, siehe \url{https://tools.ietf.org/html/rfc4180}} sind ein einfaches und maschinell gut lesbares Tabellen-Format. In diesem Datensatz sind die Werte komma-separiert. Jede Spalte entspricht einer Variable, jede Zeile einer Entscheidung. Die Variablen sind unter Punkt \ref{variablen} genauer erläutert.
#'
#' Hier empfehle ich für **R** dringend das package **data.table** (via CRAN verfügbar). Dessen Funktion **fread()** ist etwa zehnmal so schnell wie die normale **read.csv()**-Funktion in Base-R. Sie erkennt auch den Datentyp von Variablen sicherer. Ein Vorschlag:

#+ eval = FALSE, echo = TRUE
library(data.table)
dt.bverfg <- fread("filename.csv")


#+
#'## TXT-Dateien
#'Die **TXT-Dateien** inklusive Metadaten können zum Beispiel mit **R** und dem package **readtext** (via CRAN verfügbar) eingelesen werden. Ein Vorschlag:

#+ eval = FALSE, echo = TRUE
library(readtext)
df.bverfg <- readtext("*.txt",
                      docvarsfrom = "filenames", 
                      docvarnames = c("gericht",
                                      "datum",
                                      "spruchkoerper_typ",
                                      "spruchkoerper_az",
                                      "registerzeichen",
                                      "eingangsnummer",
                                      "eingangsjahr_az",
                                      "kollision",
                                      "name",
                                      "band",
                                      "seite"),
                      dvsep = "_", 
                      encoding = "UTF-8")




#+
#'# Konstruktion

#+
#'## Datenquellen

#'\begin{centering}
#'\begin{longtable}{P{5cm}p{9cm}}

#'\toprule

#' Datenquelle & Fundstelle \\

#'\midrule

#' Primäre Datenquelle & \url{https://www.bundesverfassungsgericht.de}\\
#' Source Code & \url{\softwareversionurldoi}\\
#' Entscheidungsnamen & \url{\softwareversionurldoi}\\
#' BVerfGE-Fundstellen & \url{\softwareversionurldoi}\\
#' Lebensdaten & \url{\softwareversionurldoi}\\

#'\bottomrule

#'\end{longtable}
#'\end{centering}

#' **Hinweis:** Alle auf Zenodo bereitgestellten Datenquellen wurden vom Autor persönlich für die Zwecke dieses Datensatzes erstellt.

#+
#'## Beschreibung des Datensatzes
#'Dieser Datensatz ist eine digitale Zusammenstellung von möglichst allen Entscheidungen, die auf der amtlichen Internetpräsenz des Bundesverfassungsgerichts (BVerfGE) veröffentlicht sind. Er enthält alle Entscheidungen, die auf der offiziellen Webseite des Bundesverfassungsgerichts am jeweiligen Stichtag veröffentlicht waren. Die Stichtage für jede Version entsprechen exakt der Versionsnummer.
#'
#'Zusätzlich zu den einfach maschinenlesbaren Formaten (TXT und CSV) sind die PDF-Rohdaten enthalten, damit Analysten gegebenenfalls ihre eigene Konvertierung vornehmen können. Die PDF-Rohdaten wurden inhaltlich nicht verändert und nur die Dateinamen angepasst um die Lesbarkeit für Mensch und Maschine zu verbessern.

#+
#'## Sammlung der Daten
#'Die Daten wurden unter Beachtung des Robot Exclusion Standard (RES) gesammelt. Der Abruf geschieht ausschließlich über TLS-verschlüsselte Verbindungen. Die Entscheidungen sind laut dem Gericht anonymisiert, aber ungekürzt.
#'

#+
#'## Source Code und Compilation Report
#' Der gesamte Source Code --- sowohl für die Erstellung des Datensatzes, als auch für dieses Codebook --- ist öffentlich einsehbar und dauerhaft erreichbar im wissenschaftlichen Archiv des CERN unter dieser Addresse hinterlegt: \softwareversionurldoi\
#'
#' Mit jeder Kompilierung des vollständigen Datensatzes wird auch ein umfangreicher **Compilation Report** in einem attraktiv designten PDF-Format erstellt (ähnlich diesem Codebook). Der Compilation Report enthält den vollständigen Source Code, dokumentiert relevante Rechenergebnisse, gibt sekundengenaue Zeitstempel an und ist mit einem klickbaren Inhaltsverzeichnis versehen. Er ist zusammen mit dem Source Code hinterlegt. Wenn Sie sich für Details des Erstellungs-Prozesses interessieren, lesen Sie diesen bitte zuerst.

#+
#'## Grenzen des Datensatzes
#'Nutzer sollten folgende wichtige Grenzen beachten:
#' 
#'\begin{enumerate}
#'\item Der Datensatz enthält nur das, was das Gericht auch tatsächlich veröffentlicht, nämlich begründete Entscheidungen (\emph{publication bias}).
#'\item Es kann aufgrund technischer Grenzen bzw. Fehler sein, dass manche --- im Grunde verfügbare --- Entscheidungen nicht oder nicht korrekt abgerufen werden (\emph{automation bias}).
#'\item Es werden nur PDF-Dateien abgerufen (\emph{file type bias}). Manche Entscheidungen sind nur als HTML verfügbar. Die Metadaten der Entscheidungen ohne PDF-Datei werden explizit im Compilation Report dokumentiert.
#'\item Erst ab dem Jahr 1998 sind begründete Entscheidungen des BVerfG einigermaßen vollständig veröffentlicht, auch wenn frühere Entscheidungen vereinzelt auf der Webseite verfügbar sind (\emph{temporal bias}). Die Frequenztabellen geben hierzu genauer Auskunft.
#'\end{enumerate}


#+
#'## Urheberrechtsfreiheit von Rohdaten und Datensatz 

#'An den Entscheidungstexten und amtlichen Leitsätzen besteht gem. § 5 Abs. 1 UrhG kein Urheberrecht, da sie amtliche Werke sind. § 5 UrhG ist auf amtliche Datenbanken analog anzuwenden (BGH, Beschluss vom 28.09.2006, I ZR 261/03, \enquote{Sächsischer Ausschreibungsdienst}).
#'
#' Alle eigenen Beiträge (z.B. durch Zusammenstellung und Anpassung der Metadaten) und damit den gesamten Datensatz stelle ich gemäß einer \emph{CC0 1.0 Universal Public Domain Lizenz} vollständig urheberrechtsfrei.



#+
#'## Metadaten

#+
#'### Allgemein
#'Die Metadaten wurden weitgehend aus den Hyperlinks zur jeweiligen Datei extrahiert. Hinzugefügt wurden von mir eine Reihe weitere Variablen, u.a. Gerichtsname, Entscheidungsname BVerfGE-Fundstelle, PräsidentIn, Vize-PräsidentIn, sowie Unter- und Trennstriche um die Maschinenlesbarkeit zu erleichten. Der volle Satz an Metadaten ist nur in den CSV-Dateien enthalten. Alle hinzugefügten Metadaten sind zusammen mit dem Source Code vollständig maschinenlesbar dokumentiert und liegen entweder im CSV-Format vor oder sind direkt im Source Code enthalten.
#' 
#'Die Dateinamen der PDF- und TXT-Dateien enthalten Gerichtsname, Datum (Langform nach ISO-8601, d.h. YYYY-MM-DD), den Typ des Spruchkörpers, das offizielle Aktenzeichen, eine Kollisions-ID, den Namen der Entscheidung, sowie die BVerfGE-Fundstelle (Band und Seite).


#+
#'### Schema für die Dateinamen

#'\begin{verbatim}
#'[gericht]_[datum]_[spruchkoerper_typ]_[spruchkoerper_az]_[registerzeichen]_
#'[eingangsnummer]_[eingangsjahr_az]_[kollision]_[name]_[band]_[seite]
#'\end{verbatim}

#+
#'### Beispiel eines Dateinamens

#'\begin{verbatim}
#'BVerfG_1997-07-08_S_1_BvR_1243_95_NA_Parteilehrer_96_152.txt
#'\end{verbatim}

#+
#'## Qualitätsprüfung

#'Die Typen der Variablen wurden mit \emph{regular expressions} strikt validiert. Die möglichen Werte der jeweiligen Variablen wurden zudem durch Frequenztabellen und Visualisierungen auf ihre Plausibilität geprüft. Insgesamt werden zusammen mit jeder Kompilierung Dutzende Tests zur Qualitätsprüfung durchgeführt. Alle Ergebnisse der Qualitätsprüfungen sind aggregiert im Compilation Report und einzeln im Archiv \enquote{ANALYSE} zusammen mit dem Datensatz veröffentlicht.

#+
#'## Grafische Darstellung
#'
#' Die Robenfarbe der Bundesverfassungsrichter ist \enquote{scharlachrot}. Der Hex-Wert hierfür ist \#ca2129. Das ist besonders bei der Erstellung thematisch passender Graphen hilfreich. Alle im Compilation Report und diesem Codebook präsentierten Graphen sind in diesem scharlachrot gehalten.






#+
#'# Varianten und Zielgruppen

#' Dieser Datensatz ist in verschiedenen Varianten verfügbar, die sich an unterschiedliche Zielgruppen richten. Zielgruppe sind nicht nur quantitativ forschende RechtswissenschaftlerInnen, sondern auch traditionell arbeitende JuristInnen. Idealerweise müssen quantitative Methoden ohnehin immer durch qualitative Interpretation, Theoriebildung und kritische Auseinandersetzung verstärkt werden (\emph{mixed methods approach}).
#'
#' Lehrende werden zudem von den vorbereiteten Tabellen und Diagrammen besonders profitieren, die bei der Erläuterung der Charakteristika der Daten hilfreich sein können und Zeit im universitären Alltag sparen. Alle Tabellen und Diagramme liegen auch als separate Dateien vor um sie einfach z.B. in Präsentations-Folien oder Handreichungen zu integrieren.

#'\begin{centering}
#'\begin{longtable}{P{3.5cm}p{10.5cm}}

#'\toprule

#'Variante & Zielgruppe und Beschreibung\\

#'\midrule
#'
#'\endhead

#'PDF & \textbf{Traditionelle juristische Forschung}. Die PDF-Dokumente wie sie vom Bundesverfassungsgericht auf der amtlichen Webseite bereitgestellt werden, jedoch verbessert durch semantisch hochwertige Dateinamen, die der leichteren Auffindbarkeit von Entscheidungen dienen. Die Dateinamen sind so konzipiert, dass sie auch für die traditionelle qualitative juristische Arbeit einen erheblichen Mehrwert bieten. Im Vergleich zu den CSV-Dateien enthalten die Dateinamen nur einen reduzierten Umfang an Metadaten, um Kompatibilitätsprobleme unter Windows zu vermeiden und die Lesbarkeit zu verbessern.\\
#' CSV\_Datensatz & \textbf{Legal Tech/Quantitative Forschung}. Diese CSV-Datei ist die für statistische Analysen empfohlene Variante des Datensatzes. Sie enthält den Volltext aller Entscheidungen, sowie alle in diesem Codebook beschriebenen Metadaten.\\
#' CSV\_Metadaten & \textbf{Legal Tech/Quantitative Forschung}. Wie die andere CSV-Datei, nur ohne die Entscheidungstexte. Sinnvoll für AnalystInnen, die sich nur für die Metadaten interessieren und Speicherplatz sparen wollen.\\
#' TXT & \textbf{Subsidiär für alle Zielgruppen}. Diese Variante enthält die vollständigen aus den PDF-Dateien extrahierten Entscheidungstexte, aber nur einen reduzierten Umfang an Metadaten, der dem der PDF-Dateien entspricht. Die TXT-Dateien sind optisch an das Layout der PDF-Dateien angelehnt. Geeignet für qualitative ForscherInnen, die nur wenig Speicherplatz oder eine langsame Internetverbindung zur Verfügung haben oder für quantitative ForscherInnen, die beim Einlesen der CSV-Dateien Probleme haben.\\
#' ANALYSE & \textbf{Alle Lehrenden und Forschenden}. Dieses Archiv enthält alle während dem Kompilierungs- und Prüfprozess erstellten Tabellen (CSV) und Diagramme (PDF, PNG) im Original. Sie sind inhaltsgleich mit den in diesem Codebook verwendeten Tabellen und Diagrammen. Das PDF-Format eignet sich besonders für die Verwendung in gedruckten Publikationen, das PNG-Format besonders für die Darstellung im Internet. AnalystInnen mit fortgeschrittenen Kenntnissen in R können auch auf den Source Code zurückgreifen. Empfohlen für Nutzer die einzelne Inhalte aus dem Codebook für andere Zwecke (z.B. Präsentationen, eigene Publikationen) weiterverwenden möchten.\\


#'\bottomrule

#'\end{longtable}
#'\end{centering}



#+
#'\newpage




#+
#'# Variablen

#+
#'## Hinweise

#'\begin{itemize}
#'\item Fehlende Werte sind immer mit \enquote{NA} codiert
#'\item Strings können grundsätzlich alle in UTF-8 definierten Zeichen (insbesondere Buchstaben, Zahlen und Sonderzeichen) enthalten.
#'\end{itemize}

#+
#'## Erläuterungen der einzelnen Variablen

#'\ra{1.3}
#' 
#'\begin{centering}
#'\begin{longtable}{P{3.5cm}P{3cm}p{8cm}}
#' 
#'\toprule
#' 
#'Variable & Typ & Erläuterung\\
#'
#' 
#'\midrule
#'
#'\endhead
#' 
#'doc\_id & String & (Nur CSV-Datei) Der Name der extrahierten TXT-Datei.\\
#'text  & String & (Nur CSV-Datei) Der vollständige Inhalt der Entscheidung, so wie er in der von www.bundesverfassungsgericht.de heruntergeladenen PDF-Datei dokumentiert ist.\\
#'gericht & Alphabetisch & In diesem Datensatz ist nur der Wert \enquote{BVerfG} vergeben. Dies ist der ECLI-Gerichtscode für \enquote{Bundesverfassungsgericht}. Diese Variable dient vor allem zur einfachen und transparenten Verbindung der Daten mit anderen Datensätzen.\\
#'datum & Datum & Das Datum der Entscheidung im Format YYYY-MM-DD (Langform nach ISO-8601). Die Langform ist für Menschen einfacher lesbar und wird maschinell auch öfter automatisch als Datumsformat erkannt.\\
#'spruchkoerper\_typ & Alphabetisch & Der Typ des Spruchkörpers. Es sind die Werte \enquote{K} (Kammer), \enquote{S} (Senat), \enquote{P} (Plenum) und \enquote{B} (Beschwerdekammer gem. § 97c BVerfGG) vergeben.\\
#'spruchkoerper\_az & Natürliche Zahl & Der im Aktenzeichen angegebene Spruchkörper. Es sind nur die Werte \enquote{1} und \enquote{2} vergeben. Die Werte stehen für den 1. oder 2. Senat des Gerichts. Für Verzögerungsentscheidungen der Beschwerdekammer ist der Wert \enquote{NA}. \textbf{Achtung:} Um die Entscheidungen eines bestimmten Senats zu analysieren reicht es nicht, die Variable \enquote{spruchkoerper\_az} zu nutzen, es muss zusätzlich noch die Variable \enquote{spruchkoerper\_typ} auf \enquote{S} gesetzt werden, weil ansonsten noch mit dem Senat assoziierte Entscheidungen seiner Kammern und des Plenums mit ausgewählt werden. \\
#'registerzeichen & Alphabetisch & Das amtliche Registerzeichen. Es gibt die Verfahrensart an, in der die Entscheidung ergangen ist. Eine Erläuterung der Registerzeichen findet sich unter Punkt \ref{register}.\\
#'eingangsnummer & Natürliche Zahl & Verfahren des gleichen Eingangsjahres erhalten vom Gericht eine Nummer in der Reihenfolge ihres Eingangs. Die Zahl ist in den Dateinamen mit führenden Nullen (falls <1000) codiert.\\
#'eingangsjahr\_az & Natürliche Zahl & Das im Aktenzeichen angegebene Jahr in dem das Verfahren beim Gericht anhängig wurde. Das Format ist eine zweistellige Jahreszahl (YY).\\
#'eingangsjahr\_iso & Natürliche Zahl &  (Nur CSV-Datei) Das nach ISO-8601 codierte Jahr in dem das Verfahren beim Bundesverfassungsgericht anhängig wurde. Das Format ist eine vierstellige Jahreszahl (YYYY), um eine maschinenlesbare und eindeutige Jahreszahl für den Eingang zur Verfügung zu stellen. Wurde aus der Variable \enquote{eingangsjahr\_az} durch den Autor des Datensatzes berechnet, unter der Annahme, dass Jahreszahlen über 50 dem 20. Jahrhundert zugeordnet sind und andere Jahreszahlen dem 21. Jahrhundert.\\
#'entscheidungsjahr & Natürliche Zahl & (Nur CSV-Datei) Das Jahr in dem die Entscheidung ergangen ist. Das Format ist eine vierstellige Jahreszahl (YYYY). Wurde aus der Variable \enquote{datum} durch den Autor des Datensatzes berechnet.\\
#'kollision & Alphanumerisch & In wenigen Fällen sind am gleichen Tag mehrere Entscheidungen zum gleichen Aktenzeichen ergangen. Diese werden ab der zweiten Entscheidung pro Tag durch eine Kollisions-ID mit einem Kleinbuchstaben ausdifferenziert. Für die erste Entscheidung ist der Wert der Variable \enquote{NA}, also nicht vorhanden. Die zweite Entscheidung ist mit \enquote{a} identifiziert, die dritte mit \enquote{b} und so fort. In der offiziellen Beschreibung der ECLI-Ordinalzahl wird diese Variable als \enquote{Kollisionsnummer} bezeichnet. Buchstaben sind allerdings keine Nummern, daher die abweichende Bezeichnung. In einem einzigen Fall ist tatsächlich eine \enquote{1} vergeben. Es handelt sich hier vermutlich um einen Fehler.\\
#'name & String & Der Name der Entscheidung. Für viele Entscheidungen aus der amtlichen Sammlung sind bekannte Namen vorhanden, diese wurden benutzt soweit möglich und auffindbar. Für weniger bekannte Entscheidungen wurde ein möglichst informativer Name vom Autor vergeben. Die konkrete Darstellung (ohne Leerzeichen, mit Bindestrichen usw.) ist Gründen der maschinellen Lesbarkeit geschuldet.\\
#'band & Natürliche Zahl & Der Band der amtlichen Sammlung in dem die Entscheidung veröffentlicht ist.\\
#'seite & Natürliche Zahl & Die genaue Fundstelle (Seitenzahl) der Entscheidung im jeweiligen Band der amtlichen Sammlung. Nur sinnvoll nutzbar im Zusammenspiel mit der Variable \enquote{band}.\\
#'praesi & Alphabetisch & (Nur CSV-Datei) Der Nachname des oder der PräsidentIn in dessen/deren Amtszeit das Datum der Entscheidung fällt.\\
#'v\_praesi & Alphabetisch & (Nur CSV-Datei) Der Nachname des oder der Vize-PräsidentIn in dessen/deren Amtszeit das Datum der Entscheidung fällt.\\
#'aktenzeichen & String & (Nur CSV-Datei) Das amtliche Aktenzeichen. Die Variable wurde aus den Variablen \enquote{spruchkoerper\_az}, \enquote{registerzeichen}, \enquote{eingangsnummer} und \enquote{eingangsjahr\_az} durch den Autor des Datensatzes berechnet.\\
#'ecli & String & (Nur CSV-Datei) Der European Case Law Identifier (ECLI) der Entscheidung. Jeder Entscheidung ist eine einzigartige ECLI zugewiesen, ggf. mit Kollisisions-ID. Die ECLI ist vor allem dann hilfreich, wenn dieser Datensatz mit anderen Datensätzen zusammengeführt werden und Dopplungen vermieden werden sollen. Alle inhaltlichen Bestandteile der ECLI sind in diesem Datensatz zusätzlich auch anderen und besser verständlichen Variablen zugewiesen. Nutzen Sie bevorzugt diese anderen Variablen, statt Informationen aus der ECLI zu extrahieren. Die Variable wurde aus den Variablen \enquote{entscheidungsjahr}, \enquote{spruchkoerper\_typ}, \enquote{datum}, \enquote{kollisions}, \enquote{spruchkoerper\_az}, \enquote{registerzeichen},  \enquote{eingangsnummer} und \enquote{eingangsjahr\_az} durch den Autor des Datensatzes berechnet.\\
#' tokens & Natürliche Zahl & (Nur CSV-Datei) Die Anzahl Tokens (beliebige Zeichenfolge getrennt durch whitespace) eines Dokumentes. Diese Zahl kann je nach Tokenizer und verwendeten Einstellungen erheblich schwanken. Für diese Berechnung wurde eine reine Tokenisierung ohne Entfernung von Inhalten durchgeführt. Benutzen Sie diesen Wert eher als Anhaltspunkt für die Größenordnung denn als exakte Aussage und führen sie ggf. mit ihrer eigenen Software eine Kontroll-Rechnung durch.\\
#' typen & Natürliche Zahl & (Nur CSV-Datei) Die Anzahl \emph{einzigartiger} Tokens (beliebige Zeichenfolge getrennt durch whitespace) eines Dokumentes. Diese Zahl kann je nach Tokenizer und verwendeten Einstellungen erheblich schwanken. Für diese Berechnung wurde eine reine Tokenisierung und Typenzählung ohne Entfernung von Inhalten durchgeführt. Benutzen Sie diesen Wert eher als Anhaltspunkt für die Größenordnung denn als exakte Aussage und führen sie ggf. mit ihrer eigenen Software eine Kontroll-Rechnung durch.\\
#' saetze & Natürliche Zahl & (Nur CSV-Datei) Die Anzahl Sätze. Die Definition entspricht in etwa dem üblichen Verständnis eines Satzes. Die Regeln für die Bestimmung von Satzanfang und Satzende sind im Detail allerdings sehr komplex und in \enquote{Unicode Standard Annex No 29} beschrieben. Diese Zahl kann je nach Software und verwendeten Einstellungen erheblich schwanken. Für diese Berechnung wurde eine reine Zählung ohne Entfernung von Inhalten durchgeführt. Benutzen Sie diesen Wert eher als Anhaltspunkt für die Größenordnung denn als exakte Aussage und führen sie ggf. mit ihrer eigenen Software eine Kontroll-Rechnung durch.\\
#' version & Datum & (Nur CSV-Datei) Die Versionsnummer des Datensatzes im Format YYYY-MM-DD (Langform nach ISO-8601). Die Versionsnummer entspricht immer dem Datum an dem der Datensatz erstellt und die Daten von der Webseite des Gerichts abgerufen wurden.\\
#' doi\_concept & String & (Nur CSV-Datei) Der Digital Object Identifier (DOI) des Gesamtkonzeptes des Datensatzes. Dieser ist langzeit-stabil (persistent). Über diese DOI kann via www.doi.org immer die \textbf{aktuellste Version} des Datensatzes abgerufen werden. Prinzip F1 der FAIR-Data Prinzipien (\enquote{data are assigned globally unique and persistent identifiers}) empfiehlt die Dokumentation jeder Messung mit einem persistenten Identifikator. Selbst wenn die CSV-Dateien ohne Kontext weitergegeben werden kann ihre Herkunft so immer zweifelsfrei und maschinenlesbar bestimmt werden.\\
#' doi\_version & String & (Nur CSV-Datei) Der Digital Object Identifier (DOI) der \textbf{konkreten Version} des Datensatzes. Dieser ist langzeit-stabil (persistent). Über diese DOI kann via www.doi.org immer diese konkrete Version des Datensatzes abgerufen werden. Prinzip F1 der FAIR-Data Prinzipien (\enquote{data are assigned globally unique and persistent identifiers}) empfiehlt die Dokumentation jeder Messung mit einem persistenten Identifikator. Selbst wenn die CSV-Dateien ohne Kontext weitergegeben werden kann ihre Herkunft so immer zweifelsfrei und maschinenlesbar bestimmt werden.\\
#' 
#'\bottomrule
#' 
#'\end{longtable}
#'\end{centering}





#'\newpage
#+
#'# Registerzeichen
#' 
#'\label{register}
#' 
#'\begin{centering}
#'\begin{longtable}{P{3cm}p{11cm}}
#' 
#'\toprule
#' 
#'Registerzeichen & Erläuterung\\
#' 
#'\midrule
#'
#' 
#'AR & Vorverfahren oder sonstige Verfahrensarten\\
#'BvA & Verwirkung von Grundrechten\\
#'BvB & Verfassungswidrigkeit von Parteien, Art. 21 II GG\\
#'BvC & Wahlprüfungsverfahren, Art. 41 II GG\\
#'BvD & Anklage des Bundespräsidenten, Art. 61 GG\\
#'BvE & Organstreitverfahren, Art. 93 I Nr. 1 GG\\
#'BvF & Abstrakte Normenkontrolle, Art. 93 I Nr. 2 GG\\
#'BvG & Bund-Länder-Streitigkeiten, Art.~93~Abs.~1~Nr.~3 oder Art.~84~Abs.~4~Satz~2~GG\\
#'BvK & Landesverfassungsstreitigkeiten, Art. 99 GG\\
#'BvL & Konkrete Normenkontrolle, Art. 100 I GG\\
#'BvM & Feststellung der Anwendbarkeit einer Regel des Völkergewohnheitsrechts, Art.~100~II~GG iVm Art~25~GG\\
#'BvN & Divergenzvorlagen eines Landesverfassungsgerichts zur Auslegung des Grundgesetzes, Art.~100~III~GG\\
#'BvO & Fortgeltung vorkonstitutionellen Rechts als Bundesrecht, Art.~126~GG\\
#'BvP & Sonstige durch Bundesrecht zugewiesene Verfahren, Art.~93~III~GG\\
#'BvQ & Einstweilige Anordnungen, § 32 BVerfGG\\
#'BvR & Verfassungsbeschwerden, Art.~93~Abs.~1~Nr.~4a, und Kommunalverfassungsbeschwerden,  Art.~93~Abs.~1~Nr.~4b~GG\\
#'BvT & Sonstige Verfahren\\
#'PBvS & Beendigung des Richteramtes am Bundesverfassungsgericht, §~105~BVerfGG\\
#'PBvU & Plenarentscheidungen, § 16 BVerfGG\\
#'PBvV & Rechtsgutachten, §~97~BVerfGG~a.F.\\
#'PKH & Prozesskostenhilfe\\
#'Vz & Verzögerungsrügen \\
#' 
#'\bottomrule
#' 
#'\end{longtable}
#'\end{centering}


#'\newpage
#+




#+
#'# PräsidentInnen

#+
#'## Hinweise
#' Die Daten beziehen sich auf das Amt als PräsidentIn, nicht auf die Amtszeit als VerfassungsrichterIn. Für Roman Herzog ist als Amtsende der Tag vor seinem Antritt als Bundespräsident angegeben.  Die erste Tabelle ist maschinenlesbar als CSV zusammen mit dem Source Code hinterlegt. Die zweite Tabelle ist aus der ersten berechnet.

#+
#'## Lebensdaten
setcolorder(table.praesi, c(2, 1, 3:6))

kable(table.praesi,
      format = "latex",
      align = "l",
      booktabs=TRUE,
      longtable=TRUE,
      col.names = c("Nachname",
                    "Vorname",
                    "Amtsantritt",
                    "Amtsende",
                    "Geboren",
                    "Gestorben"))

#+
#'## Dienstalter und Lebensalter
table.praesi.calc <- table.praesi[,c(1:2)]

table.praesi.calc$alter.antritt <- f.age(table.praesi$Geboren, table.praesi$AmtszeitBeginn)
table.praesi.calc$alter.abschluss <- f.age(table.praesi$Geboren, table.praesi$AmtszeitEnde)
table.praesi.calc$alter.max <- f.age(table.praesi$Geboren, table.praesi$Gestorben)


kable(table.praesi.calc,
      format = "latex",
      align = c("l", "l", "c", "c", "c"),
      booktabs=TRUE,
      longtable=TRUE,
      col.names = c("Nachname",
                    "Vorname",
                    "Alter (Amtsantritt)",
                    "Alter (Amtsende)",
                    "Alter (Tod)"))

#'\newpage
#+
#'# Vize-PräsidentInnen

#+
#'## Hinweise
#' Die Daten beziehen sich auf das Amt als Vize-PräsidentIn, nicht auf die Amtszeit als VerfassungsrichterIn. Die erste Tabelle ist maschinenlesbar als CSV zusammen mit dem Source Code hinterlegt. Die zweite Tabelle ist aus der ersten berechnet.

#+
#'## Lebensdaten
setcolorder(table.vpraesi, c(2, 1, 3:6))

kable(table.vpraesi,
      format = "latex",
      align = "l",
      booktabs=TRUE,
      longtable=TRUE,
      col.names = c("Nachname",
                    "Vorname",
                    "Amtsantritt",
                    "Amtsende",
                    "Geboren",
                    "Gestorben"))



#'\newpage
#+
#'##  Dienstalter und Lebensalter
table.vpraesi.calc <- table.vpraesi[,c(1:2)]

table.vpraesi.calc$alter.antritt <- f.age(table.vpraesi$Geboren, table.vpraesi$AmtszeitBeginn)
table.vpraesi.calc$alter.abschluss <- f.age(table.vpraesi$Geboren, table.vpraesi$AmtszeitEnde)
table.vpraesi.calc$alter.max <- f.age(table.vpraesi$Geboren, table.vpraesi$Gestorben)


kable(table.vpraesi.calc,
      format = "latex",
      align = c("l", "l", "c", "c", "c"),
      booktabs=TRUE,
      longtable=TRUE,
      col.names = c("Nachname",
                    "Vorname",
                    "Alter (Amtsantritt)",
                    "Alter (Amtsende)",
                    "Alter (Tod)"))







#'\newpage
#+
#'# Linguistische Kennzahlen

#+
#'## Erläuterung der Kennzahlen und Diagramme

#' Zur besseren Einschätzung des inhaltlichen Umfangs des Korpus dokumentiere ich an dieser Stelle die Verteilung der Werte für drei verschiedene klassische linguistische Kennzahlen:
#'
#' \medskip
#'
#'\begin{centering}
#'\begin{longtable}{P{3.5cm}p{10.5cm}}

#'\toprule

#'Kennzahl & Definition\\

#'\midrule

#' Tokens & Eine beliebige Zeichenfolge, getrennt durch whitespace-Zeichen, d.h. ein Token entspricht in der Regel einem \enquote{Wort}, kann aber gelegentlich auch sinnlose Zeichenfolgen enthalten, weil es rein syntaktisch berechnet wird.\\
#' Typen & Einzigartige Tokens. Beispiel: wenn das Token \enquote{Verfassungsrecht} zehnmal in einer Entscheidung vorhanden ist, wird es als ein Typ gezählt.\\
#' Sätze & Entsprechen in etwa dem üblichen Verständnis eines Satzes. Die Regeln für die Bestimmung von Satzanfang und Satzende sind im Detail aber sehr komplex und in \enquote{Unicode Standard Annex No 29} beschrieben.\\

#'\bottomrule

#'\end{longtable}
#'\end{centering}
#'
#' Es handelt sich bei den Diagrammen jeweils um "Density Charts", die sich besonders dafür eignen die Schwerpunkte von Variablen mit stark schwankenden numerischen Werten zu visualisieren. Die Interpretation ist denkbar einfach: je höher die Kurve, desto dichter sind in diesem Bereich die Werte der Variable. Der Wert der y-Achse kann außer Acht gelassen werden, wichtig sind nur die relativen Flächenverhältnisse und die x-Achse.
#'
#' Vorsicht bei der Interpretation: Die x-Achse it logarithmisch skaliert, d.h. in 10er-Potenzen und damit nicht-linear. Die kleinen Achsen-Markierungen zwischen den Schritten der Exponenten sind eine visuelle Hilfestellung um diese nicht-Linearität zu verstehen.
#'
#'\bigskip

#'## Werte der Kennzahlen

setnames(stats.ling, c("Kennzahl",
                       "Summe",
                       "Min",
                       "Quart1",
                       "Median",
                       "Mittel",
                       "Quart3",
                       "Max"))

kable(stats.ling,
      digits = 2,
      format.args = list(big.mark = ","),
      format = "latex",
      booktabs=TRUE,
      longtable=TRUE)



#'## Verteilung Tokens

#+ CE-BVerfG_09_Density_Tokens, fig.height = 6, fig.width = 9
ggplot(data = summary.corpus) +
    geom_density(aes(x = tokens),
                 fill = "#ca2129") +
    scale_x_log10(breaks = trans_breaks("log10", function(x) 10^x),
                  labels = trans_format("log10", math_format(10^.x)))+
    annotation_logticks(sides = "b")+
    coord_cartesian(xlim = c(1, 10^6))+
    theme_bw() +
    labs(
        title = paste(datasetname,
                      "| Version",
                      datestamp,
                      "| Verteilung der Tokens je Dokument"),
        caption = paste("DOI:",
                        doi.version),
        x = "Tokens",
        y = "Dichte"
    )+
    theme(
        text = element_text(size=14),
        plot.title = element_text(size=14, face="bold"),
        legend.position="none",
        plot.margin = margin(10, 20, 10, 10)
    )

#'## Verteilung Typen


#+ CE-BVerfG_10_Density_Typen, fig.height = 6, fig.width = 9
ggplot(data = summary.corpus) +
    geom_density(aes(x = typen),
                 fill = "#ca2129") +
    scale_x_log10(breaks = trans_breaks("log10", function(x) 10^x),
                  labels = trans_format("log10", math_format(10^.x)))+
    annotation_logticks(sides = "b")+
    coord_cartesian(xlim = c(1, 10^6))+
    theme_bw() +
    labs(
        title = paste(datasetname,
                      "| Version",
                      datestamp,
                      "| Verteilung der Typen je Dokument"),
        caption = paste("DOI:",
                        doi.version),
        x = "Typen",
        y = "Dichte"
    )+
    theme(
        text = element_text(size=14),
        plot.title = element_text(size=14, face="bold"),
        legend.position="none",
        plot.margin = margin(10, 20, 10, 10)
    )


#'## Verteilung Sätze

#+ CE-BVerfG_11_Density_Saetze, fig.height = 6, fig.width = 9
ggplot(data = summary.corpus) +
    geom_density(aes(x = saetze),
                 fill = "#ca2129") +
    scale_x_log10(breaks = trans_breaks("log10", function(x) 10^x),
                  labels = trans_format("log10", math_format(10^.x)))+
    annotation_logticks(sides = "b")+
    coord_cartesian(xlim = c(1, 10^6))+
    theme_bw() +
    labs(
        title = paste(datasetname,
                      "| Version",
                      datestamp,
                      "| Verteilung der Sätze je Dokument"),
        caption = paste("DOI:",
                        doi.version),
        x = "Sätze",
        y = "Dichte"
    )+
    theme(
        text = element_text(size=14),
        plot.title = element_text(size=14, face="bold"),
        legend.position="none",
        plot.margin = margin(10, 20, 10, 10)
    )




    
#' \newpage
#' \ra{1.4}
#+
#'# Inhalt des Korpus

#+
#'## Zusammenfassung

setnames(stats.docvars, c("Variable",
                          "Anzahl",
                          "Min",
                          "Quart1",
                          "Median",
                          "Mittel",
                          "Quart3",
                          "Max"))


kable(stats.docvars,
      digits = 2,
      format = "latex",
      booktabs=TRUE,
      longtable=TRUE)

#+
#'## Nach Spruchkörper (Aktenzeichen)


#'\vspace{0.5cm}
freqtable <- table.spruch[-.N]


#+ CE-BVerfG_03_Barplot_Spruchkoerper_AZ, fig.height = 5, fig.width = 8
ggplot(data = freqtable) +
    geom_bar(aes(x = spruchkoerper_az,
                 y = N),
             stat = "identity",
             fill ="#ca2129",
             color = "black",
             width = 0.4) +
    theme_bw() +
    labs(
        title = paste(datasetname,
                      "| Version",
                      datestamp,
                      "| Entscheidungen je Senat (Aktenzeichen)"),
        caption = paste("DOI:",
                        doi.version),
        x = "Senat",
        y = "Entscheidungen"
    )+
    theme(
        text = element_text(size=14),
        plot.title = element_text(size=14, face="bold"),
        legend.position="none",
        plot.margin = margin(10, 20, 10, 10)
    )



#'\vspace{1cm}

kable(table.spruch,
      format = "latex",
      align = 'P{3cm}',
      booktabs=TRUE,
      longtable=TRUE,
      col.names = c("Senat",
                    "Entscheidungen",
                    "% Gesamt",
                    "% Kumulativ"))





#'## Nach Registerzeichen

#'\vspace{0.5cm}
freqtable <- table.regz[-.N]

#+ CE-BVerfG_04_Barplot_Registerzeichen, fig.height = 10, fig.width = 8
ggplot(data = freqtable) +
    geom_bar(aes(x = reorder(registerzeichen, N),
                 y = N),
             stat="identity",
             fill ="#ca2129",
             color = "black") +
    coord_flip()+
    theme_bw() +
    labs(
        title = paste(datasetname,
                      "| Version",
                      datestamp,
                      "| Entscheidungen je Registerzeichen"),
        caption = paste("DOI:",
                        doi.version),
        x = "Registerzeichen",
        y = "Entscheidungen"
    )+
    theme(
        text = element_text(size=14),
        plot.title = element_text(size=14, face="bold"),
        legend.position="none",
        plot.margin = margin(10, 20, 10, 10)
    )


#'\newpage

kable(table.regz,
      format = "latex",
      align = 'P{3cm}',
      booktabs=TRUE,
      longtable=TRUE,
      col.names = c("Registerzeichen",
                    "Entscheidungen",
                    "% Gesamt",
                    "% Kumulativ"))


#'\newpage
#'## Nach PräsidentIn

#'\vspace{0.5cm}
freqtable <- table.output.praesi[-.N]

#+ CE-BVerfG_05_Barplot_PraesidentIn, fig.height = 5.5, fig.width = 8
ggplot(data = freqtable) +
    geom_bar(aes(x = reorder(praesi, N),
                 y = N),
             stat="identity",
             fill ="#ca2129",
             color = "black") +
    coord_flip()+
    theme_bw() +
    labs(
        title = paste(datasetname,
                      "| Version",
                      datestamp,
                      "| Entscheidungen je PräsidentIn"),
        caption = paste("DOI:",
                        doi.version),
        x = "PräsidentIn",
        y = "Entscheidungen"
    )+
    theme(
        axis.title.y=element_blank(),
        text = element_text(size=14),
        plot.title = element_text(size=14, face="bold"),
        legend.position="none",
        plot.margin = margin(10, 20, 10, 10)
    )

#'\vspace{0.5cm}

kable(table.output.praesi,
      format = "latex",
      align = 'P{3cm}',
      booktabs=TRUE,
      longtable=TRUE,
      col.names = c("PräsidentIn",
                    "Entscheidungen",
                    "% Gesamt",
                    "% Kumulativ"))


#'\newpage
#'## Nach Vize-PräsidentIn

#'\vspace{0.5cm}
freqtable <- table.output.vpraesi[-.N]


#+ CE-BVerfG_06_Barplot_VizePraesidentIn, fig.height = 5.5, fig.width = 8
ggplot(data = freqtable) +
    geom_bar(aes(x = reorder(v_praesi, N),
                 y = N),
             stat="identity",
             fill ="#ca2129",
             color = "black") +
    coord_flip()+
    theme_bw() +
    labs(
        title = paste(datasetname,
                      "| Version",
                      datestamp,
                      "| Entscheidungen je Vize-PräsidentIn"),
        caption = paste("DOI:",
                        doi.version),
        x = "Vize-PräsidentIn",
        y = "Entscheidungen"
    )+
    theme(
        axis.title.y=element_blank(),
        text = element_text(size=14),
        plot.title = element_text(size=14, face="bold"),
        legend.position="none",
        plot.margin = margin(10, 20, 10, 10)
    )


#'\vspace{0.5cm}

kable(table.output.vpraesi,
      format = "latex",
      align = 'P{3cm}',
      booktabs=TRUE,
      longtable=TRUE,
      col.names = c("Vize-PräsidentIn",
                    "Entscheidungen",
                    "% Gesamt",
                    "% Kumulativ"))






#' \newpage
#+
#'## Nach Entscheidungsjahr

#'\vspace{0.5cm}
freqtable <- table.jahr.entscheid[-.N][,lapply(.SD, as.numeric)]

#+ CE-BVerfG_07_Barplot_Entscheidungsjahr, fig.height = 7, fig.width = 11
ggplot(data = freqtable) +
    geom_bar(aes(x = entscheidungsjahr,
                 y = N),
             stat="identity",
             fill ="#ca2129") +
    theme_bw() +
    labs(
        title = paste(datasetname,
                      "| Version",
                      datestamp,
                      "| Entscheidungen je Entscheidungsjahr"),
        caption = paste("DOI:",
                        doi.version),
        x = "Entscheidungsjahr",
        y = "Entscheidungen"
    )+
    theme(
        text = element_text(size=16),
        plot.title = element_text(size=16, face="bold"),
        legend.position="none",
        plot.margin = margin(10, 20, 10, 10)
    )

#'\vspace{1cm}

kable(table.jahr.entscheid,
      format = "latex",
      align = 'P{3cm}',
      booktabs=TRUE,
      longtable=TRUE,
      col.names = c("Jahr",
                    "Entscheidungen",
                    "% Gesamt",
                    "% Kumulativ")) %>% kable_styling(latex_options = "repeat_header")




#'\newpage
#+
#'## Nach Eingangsjahr (ISO)


#'\vspace{0.5cm}


freqtable <- table.jahr.eingangISO[-.N][,lapply(.SD, as.numeric)]


#+ CE-BVerfG_08_Barplot_EingangsjahrISO, fig.height = 7, fig.width = 11
ggplot(data = freqtable) +
    geom_bar(aes(x = eingangsjahr_iso,
                 y = N),
             stat="identity",
             fill ="#ca2129") +
    theme_bw() +
    labs(
        title = paste(datasetname,
                      "| Version",
                      datestamp,
                      "| Entscheidungen je Eingangsjahr (ISO)"),
        caption = paste("DOI:",
                        doi.version),
        x = "Eingangsjahr (ISO)",
        y = "Entscheidungen"
    )+
    theme(
        text = element_text(size=16),
        plot.title = element_text(size=16, face="bold"),
        legend.position="none",
        plot.margin = margin(10, 20, 10, 10)
    )

#'\vspace{1cm}

kable(freqtable[,c(1:2,4:5)],
      format = "latex",
      align = 'P{3cm}',
      booktabs=TRUE,
      longtable=TRUE,
      col.names = c("Jahr",
                    "Entscheidungen",
                    "% Gesamt",
                    "% Kumulativ")) %>% kable_styling(latex_options = "repeat_header")





#'# Dateigrößen

files.zip <- fread(hashfile)$filename
filesize <- round(file.size(files.zip) / 10^6, digits = 2)

table.size <- data.table(files.zip,
                         filesize)


kable(table.size,
      format = "latex",
      align = c("l", "r"),
      booktabs=TRUE,
      longtable=TRUE,
      col.names = c("Datei",
                    "Größe in MB"))


#'\bigskip
#' ![](ANALYSE/CE-BVerfG_12_Density_Dateigroessen-1.pdf)




#'\newpage
#+
#'# Signaturprüfung

#+
#'## Allgemeines
#' Die Integrität und Echtheit der einzelnen Archive des Datensatzes sind durch eine Zwei-Phasen-Signatur sichergestellt. In Phase I werden während der Kompilierung für jedes ZIP-Archiv Hash-Werte in zwei verschiedenen Verfahren berechnet und in einer CSV-Datei dokumentiert. In Phase II wird diese CSV-Datei mit meinem persönlichen geheimen GPG-Schlüssel signiert. Dieses Verfahren stellt sicher, dass die Kompilierung von jedermann durchgeführt werden kann, insbesondere im Rahmen von Replikationen, die persönliche Gewähr für Ergebnisse aber dennoch vorhanden ist.
#'
#' Dieses Codebook ist vollautomatisch erstellt und prüft die kryptographisch sicheren SHA3-512 Signaturen (\enquote{hashes}) aller ZIP-Archive, sowie die GPG-Signatur der CSV-Datei, welche die SHA3-512 Signaturen enthält. SHA3-512 Signaturen werden durch einen system call zur OpenSSL library auf Linux-Systemen berechnet. Eine erfolgreiche Prüfung meldet \enquote{Signatur verifiziert!}. Eine gescheiterte Prüfung meldet \enquote{FEHLER!}

#+
#'## Persönliche GPG-Signatur
#' Die während der Kompilierung des Datensatzes erstellte CSV-Datei mit den Hash-Prüfsummen ist mit meiner persönlichen GPG-Signatur versehen. Der mit dieser Version korrespondierende Public Key ist sowohl mit dem Datensatz als auch mit dem Source Code hinterlegt. Er hat folgende Kenndaten:
#' 
#' **Name:** Sean Fobbe (fobbe-data@posteo.de)
#' 
#' **Fingerabdruck:** FE6F B888 F0E5 656C 1D25  3B9A 50C4 1384 F44A 4E42

#+
#'## Import: Public Key
#+ echo = TRUE
system2("gpg2", "--import GPG-Public-Key_Fobbe-Data.asc",
        stdout = TRUE,
        stderr = TRUE)




#'\newpage
#+
#'## Prüfung: GPG-Signatur der Hash-Datei

#+ echo = TRUE

# CSV-Datei mit Hashes
print(hashfile)
# GPG-Signatur
print(signaturefile)

# GPG-Signatur prüfen
testresult <- system2("gpg2",
                      paste("--verify", signaturefile, hashfile),
                      stdout = TRUE,
                      stderr = TRUE)

# Anführungsstriche entfernen um Anzeigefehler zu vermeiden
testresult <- gsub('"', '', testresult)

#+ echo = TRUE
kable(testresult, format = "latex", booktabs=TRUE,
      longtable=TRUE, col.names = c("Ergebnis"))


#'\newpage
#+
#'## Prüfung: SHA3-512 Hashes der ZIP-Archive
#+ echo = TRUE

# Prüf-Funktion definieren
sha3test <- function(filename, sig){
    sig.new <- system2("openssl",
                       paste("sha3-512", filename),
                       stdout = TRUE)
    sig.new <- gsub("^.*\\= ", "", sig.new)
    if (sig == sig.new){
        return("Signatur verifiziert!")
    }else{
        return("FEHLER!")
    }
}

# Ursprüngliche Signaturen importieren
table.hashes <- fread(hashfile)
filename <- table.hashes$filename
sha3.512 <- table.hashes$sha3.512

# Signaturprüfung durchführen 
sha3.512.result <- mcmapply(sha3test, filename, sha3.512, USE.NAMES=FALSE)

# Ergebnis anzeigen
testresult <- data.table(filename, sha3.512.result)

#+ echo = TRUE
kable(testresult, format = "latex", booktabs=TRUE,
      longtable=TRUE, col.names = c("Datei", "Ergebnis"))




#+
#'# Changelog
#'
#'\ra{1.3}
#'
#' 
#'\begin{centering}
#'\begin{longtable}{p{2.5cm}p{11.5cm}}
#'\toprule
#'Version &  Details\\
#'\midrule
#'
#' \version  &
#'
#' \begin{itemize}
#' \item Vollständige Aktualisierung der Daten
#' \item Veröffentlichung des vollständigen Source Codes
#' \item Deutliche Erweiterung des inhaltlichen Umfangs des Codebooks
#' \item Einführung der vollautomatischen Erstellung von Datensatz und Codebook
#' \item Einführung von Compilation Reports um den Erstellungsprozess exakt zu dokumentieren
#' \item Einführung von Variablen für Versionsnummer, Concept DOI, Version DOI, ECLI, Entscheidungsnamen, BVerfGE-Band, BVerfGE-Seite, Typ des Spruchkörpers, PräsidentIn, Vize-PräsidentIn und linguistische Kennzahlen (Tokens, Typen, Sätze)
#' \item Automatisierung und Erweiterung der Qualitätskontrolle
#' \item Einführung von Diagrammen zur Visualisierung von Prüfergebnissen
#' \item Einführung kryptographischer Signaturen
#' \item Alle Variablen sind nun in Kleinschreibung und Snake Case gehalten
#' \item Variable \enquote{Suffix} in \enquote{kollision} umbenannt.
#' \item Variable \enquote{Ordinalzahl} in \enquote{eingangsnummer} umbenannt.
#' \end{itemize}\\
#' 
#'2020-08-03  &
#'
#'\begin{itemize}
#'\item Vollständige Aktualisierung der Daten
#'\item Angleichung der Variablen-Namen an andere Datensätze der CE-Serie von \url{https://zenodo.org/communities/sean-fobbe-data/}
#'\item Einführung der Variable \enquote{Suffix} um weitere Entscheidungen korrekt erfassen zu können; aufgrund der fehlenden Berücksichtigung des Suffix sind die Metadaten von 36 Entscheidungen der Version 2020-06-20 fehlerhaft. Bitte verwenden Sie daher nur die neue Version. Alternativ können Sie die fehlerhaften Dateien (erkennbar an einem dreistelligen Eingangsjahr) aus der Analyse ausschließen oder per Hand korrigieren.
#'\end{itemize}\\
#' 
#'2020-06-20  &
#'
#' \begin{itemize}
#' \item Erstveröffentlichung
#' \end{itemize}\\
#' 
#'\bottomrule
#'\end{longtable}
#'\end{centering}

#'\newpage
#+
#'# Parameter für strenge Replikationen

system2("openssl",  "version", stdout = TRUE)

sessionInfo()

#'# Literaturverzeichnis
